@@ -3,5 +3,5 @@ from rest_framework.authtoken import views as auth
 from . import views
 
 urlpatterns = [
-    path(r'^$', views.index, name='index'),
+    path(r'$', views.index, name='index'),
 ]
